# Supports Organizer.rb
=begin rdoc
= Random Painter
Copyright 2009, Chris Fullmer
All Rights Reserved

== Disclaimer
THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

== License
This software is distributed under the Smustard End User License Agreement
http://www.smustard.com/eula

== Information
Author:: Chris Fullmer
Organization:: www.ChrisFullmer.com and distributed on www.sketchucation.com
Name:: Random Painter
Version:: v1.1
SU Version:: Developed on SU 7, should be compatible with 6 and 5 at least.
Date:: March 09, 2009
Description:: This script will take the selection and paint it random colors that the user inputs.
Usage:: Select the items to be painted.  Run the script from the Plugins Menu.  You will get a color palette window.  Select the color from there that you would like to use.  When finished choosing colors, it will randomly apply the colors to all faces.  It does not apply colors to edges, groups or components.
Requires::  WxSU from http://sourceforge.net/project/showfiles.php?group_id=240585&package_id=292646&release_id=631835 from and progressbar.rb from http://www.smustard.com/script/ProgressBar
History::
0.1:: 2009-02-07
   * First release
0.2:: 2009-02-07
   * Added WxSU color palette to help with the color selection
   * Therefore it now requires the WxSU plugin also 
0.3:: 2009-02-07
   * Asks if you want to paint the backface
1.0:: 2009-03-07
   * Update rdoc compatiblity
   * New license info to conform to Smustards EULA
1.1:: 2009-03-09
   * New menu location - Plugins>Chris Fullmer Tools>Random Painter
=end

require "sketchup.rb"
require "wxSU.rb"

# Wrapping the whole script into a module with a very unique name so as to not let any of my
# methods or variables interefere with anyone else's scripts.
module Clf_painter
	def Clf_painter.rand_painter
		
		#Sets the selection for this ruby to whatever is currently selected
		model = Sketchup.active_model
		clselection = model.selection
		#If nothing is selected, then it returns an message to select something first
		if clselection.empty?
		    UI.messagebox "Please select the faces to be painted first"
		    resturn
		end
		
		# Initialize a couple of arrays and a variable for use later
		results = []
		color = []
		count = 0
		more_color = 1
		
		# Starts the color input dialog box.  The silly thing returns a horrible string that I have to parse
		# I'm sure there is a better way to pull out the RGB values from it, but this seems to work well eoungh.
		while more_color == 1		
			color_dialog = Wx::ColourDialog.new(WxSU.app.sketchup_frame)
			color_dialog.show_modal
			color_string = color_dialog.get_colour_data.get_colour.to_s
			color_string[0..14]= ""
			color_string[(color_string.length - 7)..(color_string.length)]= ""
			color_array = color_string.split(/, /)
			color.push color_array
			mb_answer = UI.messagebox( "Choose another color?", MB_YESNOCANCEL, "Random Color Painter" )
			more_color = 0
			if mb_answer == 2
				return nil
			end
			if mb_answer == 6
				more_color = 1
			end
		end
		
		# Decide if we're going to paint the backside of the face too
		mb_backface = UI.messagebox( "Paint the backsides of faces too?", MB_YESNOCANCEL, "Random Color Painter" )
		if mb_backface == 2
			return nil
		end
		if mb_backface == 6
			paint_back = 0
		end
		if mb_backface == 7
			paint_back = 1
		end
		
		# Decides what version of SU is being run and then begins the group of operatiosn for the undo command.  Uses the
		#fast code (true) if using version 7.
		a = Sketchup.version
		b = a[0,1].to_i
		if b > 6
			model.start_operation("Random Color", true)
		else
			model.start_operation("Random Color")
		end
		
		# This takes the selection and runs through each entity selected and decides if it is a face.  
		# If it is a face, then one of the colors previously input by the user gets applied to it.
		clselection.each do
			clent = clselection[count]
		  	if clent.typename == ("Face")
				rand_col = rand(color.length).to_i
				paintcolor = color[rand_col]
				clent.material = [paintcolor[0].to_i, paintcolor[1].to_i, paintcolor[2].to_i]
				if paint_back == 0
					clent.back_material = [paintcolor[0].to_i, paintcolor[1].to_i, paintcolor[2].to_i]
				end
			end
			count = count + 1
		end
		
		# This closes the undo stack.  Everything between the start and commit are looked at as a single undo command.
		model.commit_operation
	end
end

if( $submenu )
	organizer = $submenu 
	if !file_loaded?(__FILE__) then
		organizer.add_item("Random Painter") { Clf_painter.rand_painter }
	end
else
	if !file_loaded?('clf_menu_loader') then
		$clf_tools_menu = UI.menu("Plugins").add_submenu("Chris Fullmer Tools")
	end
	if !file_loaded?(__FILE__) then
		$clf_tools_menu.add_item("Random Painter") { Clf_painter.rand_painter }
	end
end

file_loaded('clf_menu_loader')
file_loaded(__FILE__)